/*
** Module   : RectangleGuiImpl.java
** Abstract : GUI rectangle widget implementation.
**
** Copyright (c) 2014, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 MAG 20141023 Create first release.
*/

package com.goldencode.p2j.ui.client.gui;

import com.goldencode.p2j.ui.*;
import com.goldencode.p2j.ui.client.*;
import com.goldencode.p2j.ui.client.gui.driver.*;

/**
 * An implementation of RECTANGLE widget.
 */
@SuppressWarnings("unchecked")
public class RectangleGuiImpl
extends Rect<GuiOutputManager>
{
   /** Screen driver */
   private GuiDriver gd;
   
   /** Color resolver */
   private GuiColorResolver gc;

   /**
    * Special constructor used to restore component using given configuration.
    * <p>
    * Call {@link #initialize} to finish the widget initialization.
    * 
    * @param   id
    *          The widget's ID.
    * @param   cfg
    *          Configuration data.
    */
   public RectangleGuiImpl(WidgetId id, WidgetConfig cfg)
   {
      super(id, (RectangleConfig) cfg);
      gd = (GuiDriver) OutputManager.getDriver();
      gc = new GuiColorResolver(gd, config(), SysColor.COLOR_WINDOW, SysColor.COLOR_WINDOWTEXT);
   }
   
   @Override
   public void draw()
   {
      // draw only if is visible.
      if (!isVisible())
      {
         return;
      }
      
      // determine colors
      gc.colors();
               
      final NativePoint p = physicalLocation();
      final NativeDimension d = physicalDimension();

      final NativeRectangle clip = clipRectangle(p, d);

      gd.draw(p, clip, new Runnable()
      {

         @Override
         public void run()
         {
            // simple rectangle
            gd.setColor(gc.fgColor);
            gd.drawRect(0, 0, d.width-1, d.height-1);
         }
         
      });
   }
}
